Module bytecode

Module bytecode 

The bytecode representation of Mica.

Structs

BuiltinDispatchTables
Dispatch tables for instances of builtin types. These should be constructed by the standard library.
BuiltinTraits
IDs of built-in traits and their methods.
Chunk
A chunk of bytecode.
DispatchTable
A dispatch table containing functions bound to an instance of a value.
Environment
An environment containing information about declared globals, functions, vtables.
Function
A function prototype.
FunctionSignature
The signature of a function (its name, argument count, and enclosing trait).
JumpTooFar
A jump was constructed whose offset stretched too far.
Opr24
A 24-bit integer encoding an instruction operand.
TraitPrototype
The prototype of a trait. Contains a list of all method IDs the trait must implement.
U32TooBig
A u32 is too big to fit in an Opr24.

Enums

CaptureKind
The kind of an upvalue capture.
Control
The kind of a controlling function.
FunctionKind
The kind of the function (bytecode or FFI).
Opcode
A VM opcode.

Traits

EncodeInstruction
Types that can be encoded into bytecode.
PackableToOpr24

Type Aliases

ForeignFunction
The ABI of a raw foreign function.