pub struct BuiltinDispatchTables {
pub nil: Gc<DispatchTable>,
pub boolean: Gc<DispatchTable>,
pub number: Gc<DispatchTable>,
pub string: Gc<DispatchTable>,
pub function: Gc<DispatchTable>,
pub list: Gc<DispatchTable>,
pub dict: Gc<DispatchTable>,
}Expand description
Dispatch tables for instances of builtin types. These should be constructed by the standard library.
Fields
nil: Gc<DispatchTable>boolean: Gc<DispatchTable>number: Gc<DispatchTable>string: Gc<DispatchTable>function: Gc<DispatchTable>list: Gc<DispatchTable>dict: Gc<DispatchTable>Implementations
Sourceimpl BuiltinDispatchTables
Default dispatch tables for built-in types are empty and do not implement any methods.
impl BuiltinDispatchTables
Default dispatch tables for built-in types are empty and do not implement any methods.