DispatchTable

Struct DispatchTable 

pub struct DispatchTable {
    pub pretty_name: Rc<str>,
    pub type_name: Rc<str>,
    pub instance: Option<GcRaw<DispatchTable>>,
    /* private fields */
}
A dispatch table containing functions bound to an instance of a value.

Fields

pretty_name: Rc<str>

The pretty name of the type this dispatch table contains functions for.

type_name: Rc<str>instance: Option<GcRaw<DispatchTable>>

The “child” dispatch table that holds instance methods.

Implementations

Source

impl DispatchTable

pub fn new_for_type(type_name: impl Into<Rc<str>>) -> Self

Creates a new, empty type dispatch table with the given type name.

pub fn new_for_instance(type_name: impl Into<Rc<str>>) -> Self

Creates a new, empty instance dispatch table with the given type name.

pub fn get_method(&self, index: u16) -> Option<GcRaw<Closure>>

Returns a reference to the method at the given index.

pub fn set_method(&mut self, index: u16, closure: GcRaw<Closure>)

Adds a method into the dispatch table.