pub struct Function {
pub name: Rc<str>,
pub parameter_count: Option<u16>,
pub kind: FunctionKind,
pub hidden_in_stack_traces: bool,
}Expand description
A function prototype.
Fields
name: Rc<str>parameter_count: Option<u16>kind: FunctionKindSet to true if the function is to be hidden in stack traces.
This is useful for functions that are implementation details, such as trait function shims.