pub struct FunctionSignature {
pub name: Rc<str>,
pub arity: Option<u16>,
pub trait_id: Option<Opr24>,
}Expand description
The signature of a function (its name, argument count, and enclosing trait).
Fields
name: Rc<str>arity: Option<u16>This arity number does not include the implicit self argument.
trait_id: Option<Opr24>The index of the trait this signature belongs to.
When None, the function is free and does not belong to any trait.
Implementations