RenderedSignature

Struct RenderedSignature 

pub struct RenderedSignature {
    pub name: Rc<str>,
    pub arity: Option<u16>,
    pub trait_name: Option<Rc<str>>,
}
A FunctionSignature that can be rendered into text. One can be obtained by calling FunctionSignature::render.

Fields

name: Rc<str>arity: Option<u16>

This arity number does not include the implicit self argument.

trait_name: Option<Rc<str>>

The index of the trait this signature belongs to. When None, the function is free and does not belong to any trait.

Implementations

Source

impl RenderedSignature

pub const INVALID_NAME: &'static str = ""

The empty string name is considered to be the invalid name, and will result in different Display.

pub fn invalid() -> Self

pub fn is_invalid(&self) -> bool