The bytecode representation of Mica.
Structs
- Builtin
Dispatch Tables - Dispatch tables for instances of builtin types. These should be constructed by the standard library.
- Builtin
Traits - IDs of built-in traits and their methods.
- Chunk
- A chunk of bytecode.
- Dispatch
Table - A dispatch table containing functions bound to an instance of a value.
- Environment
- An environment containing information about declared globals, functions, vtables.
- Function
- A function prototype.
- Function
Signature - The signature of a function (its name, argument count, and enclosing trait).
- Jump
TooFar - A jump was constructed whose offset stretched too far.
- Opr24
- A 24-bit integer encoding an instruction operand.
- Trait
Prototype - The prototype of a trait. Contains a list of all method IDs the trait must implement.
- U32Too
Big - A u32 is too big to fit in an
Opr24.
Enums
- Capture
Kind - The kind of an upvalue capture.
- Control
- The kind of a controlling function.
- Function
Kind - The kind of the function (bytecode or FFI).
- Opcode
- A VM opcode.
Traits
- Encode
Instruction - Types that can be encoded into bytecode.
- Packable
ToOpr24
Type Aliases
- Foreign
Function - The ABI of a raw foreign function.